from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TDF import *
from OCC.Core.CDF import *
from OCC.Core.TCollection import *
from OCC.Core.PCDM import *
from OCC.Core.Message import *
from OCC.Core.TColStd import *
from OCC.Core.Resource import *
from OCC.Core.CDM import *

TDocStd_XLinkPtr = NewType('TDocStd_XLinkPtr', TDocStd_XLink)

class TDocStd_SequenceOfApplicationDelta:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TDocStd_SequenceOfDocument:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class tdocstd:
	@staticmethod
	def IDList(anIDList: TDF_IDList) -> None: ...

class TDocStd_Application(CDF_Application):
	def __init__(self) -> None: ...
	def Close(self, aDoc: TDocStd_Document) -> None: ...
	def DefineFormat(self, theFormat: TCollection_AsciiString, theDescription: TCollection_AsciiString, theExtension: TCollection_AsciiString, theReader: PCDM_RetrievalDriver, theWriter: PCDM_StorageDriver) -> None: ...
	def GetDocument(self, index: int, aDoc: TDocStd_Document) -> None: ...
	def InitDocument(self, aDoc: TDocStd_Document) -> None: ...
	def IsDriverLoaded(self) -> bool: ...
	def IsInSession(self, path: TCollection_ExtendedString) -> int: ...
	def NbDocuments(self) -> int: ...
	def NewDocument(self, format: TCollection_ExtendedString, aDoc: TDocStd_Document) -> None: ...
	def OnAbortTransaction(self, theDoc: TDocStd_Document) -> None: ...
	def OnCommitTransaction(self, theDoc: TDocStd_Document) -> None: ...
	def OnOpenTransaction(self, theDoc: TDocStd_Document) -> None: ...
	@overload
	def Open(self, path: TCollection_ExtendedString, aDoc: TDocStd_Document, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> PCDM_ReaderStatus: ...
	def ReadingFormats(self, theFormats: TColStd_SequenceOfAsciiString) -> None: ...
	def Resources(self) -> Resource_Manager: ...
	def ResourcesName(self) -> str: ...
	@overload
	def Save(self, aDoc: TDocStd_Document, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> PCDM_StoreStatus: ...
	@overload
	def Save(self, aDoc: TDocStd_Document, theStatusMessage: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> PCDM_StoreStatus: ...
	@overload
	def SaveAs(self, aDoc: TDocStd_Document, path: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> PCDM_StoreStatus: ...
	@overload
	def SaveAs(self, aDoc: TDocStd_Document, path: TCollection_ExtendedString, theStatusMessage: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> PCDM_StoreStatus: ...
	def WritingFormats(self, theFormats: TColStd_SequenceOfAsciiString) -> None: ...

class TDocStd_ApplicationDelta(Standard_Transient):
	def __init__(self) -> None: ...
	def GetDocuments(self) -> TDocStd_SequenceOfDocument: ...
	def GetName(self) -> TCollection_ExtendedString: ...
	def SetName(self, theName: TCollection_ExtendedString) -> None: ...

class TDocStd_CompoundDelta(TDF_Delta):
	def __init__(self) -> None: ...

class TDocStd_Context:
	def __init__(self) -> None: ...
	def ModifiedReferences(self) -> bool: ...
	def SetModifiedReferences(self, Mod: bool) -> None: ...

class TDocStd_Document(CDM_Document):
	def __init__(self, astorageformat: TCollection_ExtendedString) -> None: ...
	def AbortCommand(self) -> None: ...
	def BeforeClose(self) -> None: ...
	def ChangeStorageFormat(self, newStorageFormat: TCollection_ExtendedString) -> None: ...
	def ClearRedos(self) -> None: ...
	def ClearUndos(self) -> None: ...
	def CommitCommand(self) -> bool: ...
	def EmptyLabelsSavingMode(self) -> bool: ...
	@staticmethod
	def Get(L: TDF_Label) -> TDocStd_Document: ...
	def GetAvailableRedos(self) -> int: ...
	def GetAvailableUndos(self) -> int: ...
	def GetData(self) -> TDF_Data: ...
	def GetModified(self) -> TDF_LabelMap: ...
	def GetName(self) -> TCollection_ExtendedString: ...
	def GetPath(self) -> TCollection_ExtendedString: ...
	def GetRedos(self) -> TDF_DeltaList: ...
	def GetSavedTime(self) -> int: ...
	def GetUndoLimit(self) -> int: ...
	def GetUndos(self) -> TDF_DeltaList: ...
	def HasOpenCommand(self) -> bool: ...
	def InitDeltaCompaction(self) -> bool: ...
	def IsChanged(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def IsNestedTransactionMode(self) -> bool: ...
	def IsSaved(self) -> bool: ...
	def IsValid(self) -> bool: ...
	def Main(self) -> TDF_Label: ...
	def ModificationMode(self) -> bool: ...
	def NewCommand(self) -> None: ...
	def OpenCommand(self) -> None: ...
	def PerformDeltaCompaction(self) -> bool: ...
	def PurgeModified(self) -> None: ...
	def Recompute(self) -> None: ...
	def Redo(self) -> bool: ...
	def RemoveFirstUndo(self) -> None: ...
	def SetData(self, data: TDF_Data) -> None: ...
	def SetEmptyLabelsSavingMode(self, isAllowed: bool) -> None: ...
	def SetModificationMode(self, theTransactionOnly: bool) -> None: ...
	def SetModified(self, L: TDF_Label) -> None: ...
	def SetNestedTransactionMode(self, isAllowed: Optional[bool] = True) -> None: ...
	def SetSaved(self) -> None: ...
	def SetSavedTime(self, theTime: int) -> None: ...
	def SetUndoLimit(self, L: int) -> None: ...
	def StorageFormat(self) -> TCollection_ExtendedString: ...
	def Undo(self) -> bool: ...
	def Update(self, aToDocument: CDM_Document, aReferenceIdentifier: int, aModifContext: None) -> None: ...
	def UpdateReferences(self, aDocEntry: TCollection_AsciiString) -> None: ...

class TDocStd_Modified(TDF_Attribute):
	def __init__(self) -> None: ...
	@staticmethod
	def Add(alabel: TDF_Label) -> bool: ...
	def AddLabel(self, L: TDF_Label) -> bool: ...
	@overload
	@staticmethod
	def Clear(access: TDF_Label) -> None: ...
	@overload
	def Clear(self) -> None: ...
	@staticmethod
	def Contains(alabel: TDF_Label) -> bool: ...
	@overload
	@staticmethod
	def Get(access: TDF_Label) -> TDF_LabelMap: ...
	@overload
	def Get(self) -> TDF_LabelMap: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	@staticmethod
	def IsEmpty(access: TDF_Label) -> bool: ...
	@overload
	def IsEmpty(self) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	@staticmethod
	def Remove(alabel: TDF_Label) -> bool: ...
	def RemoveLabel(self, L: TDF_Label) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...

class TDocStd_MultiTransactionManager(Standard_Transient):
	def __init__(self) -> None: ...
	def AbortCommand(self) -> None: ...
	def AddDocument(self, theDoc: TDocStd_Document) -> None: ...
	def ClearRedos(self) -> None: ...
	def ClearUndos(self) -> None: ...
	@overload
	def CommitCommand(self) -> bool: ...
	@overload
	def CommitCommand(self, theName: TCollection_ExtendedString) -> bool: ...
	def Documents(self) -> TDocStd_SequenceOfDocument: ...
	def GetAvailableRedos(self) -> TDocStd_SequenceOfApplicationDelta: ...
	def GetAvailableUndos(self) -> TDocStd_SequenceOfApplicationDelta: ...
	def GetUndoLimit(self) -> int: ...
	def HasOpenCommand(self) -> bool: ...
	def IsNestedTransactionMode(self) -> bool: ...
	def ModificationMode(self) -> bool: ...
	def OpenCommand(self) -> None: ...
	def Redo(self) -> None: ...
	def RemoveDocument(self, theDoc: TDocStd_Document) -> None: ...
	def RemoveLastUndo(self) -> None: ...
	def SetModificationMode(self, theTransactionOnly: bool) -> None: ...
	def SetNestedTransactionMode(self, isAllowed: Optional[bool] = True) -> None: ...
	def SetUndoLimit(self, theLimit: int) -> None: ...
	def Undo(self) -> None: ...

class TDocStd_Owner(TDF_Attribute):
	def __init__(self) -> None: ...
	@overload
	@staticmethod
	def GetDocument(ofdata: TDF_Data) -> TDocStd_Document: ...
	@overload
	def GetDocument(self) -> TDocStd_Document: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def SetDocument(indata: TDF_Data, doc: TDocStd_Document) -> None: ...
	@overload
	@staticmethod
	def SetDocument(indata: TDF_Data, doc: TDocStd_Document) -> None: ...
	@overload
	def SetDocument(self, document: TDocStd_Document) -> None: ...
	@overload
	def SetDocument(self, document: TDocStd_Document) -> None: ...

class TDocStd_PathParser:
	def __init__(self, path: TCollection_ExtendedString) -> None: ...
	def Extension(self) -> TCollection_ExtendedString: ...
	def Length(self) -> int: ...
	def Name(self) -> TCollection_ExtendedString: ...
	def Parse(self) -> None: ...
	def Path(self) -> TCollection_ExtendedString: ...
	def Trek(self) -> TCollection_ExtendedString: ...

class TDocStd_XLink(TDF_Attribute):
	def __init__(self) -> None: ...
	def AfterAddition(self) -> None: ...
	def AfterUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def BackupCopy(self) -> TDF_Attribute: ...
	def BeforeRemoval(self) -> None: ...
	def BeforeUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	@overload
	def DocumentEntry(self, aDocEntry: TCollection_AsciiString) -> None: ...
	@overload
	def DocumentEntry(self) -> TCollection_AsciiString: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	def LabelEntry(self, aLabel: TDF_Label) -> None: ...
	@overload
	def LabelEntry(self, aLabEntry: TCollection_AsciiString) -> None: ...
	@overload
	def LabelEntry(self) -> TCollection_AsciiString: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, intoAttribute: TDF_Attribute, aRelocationTable: TDF_RelocationTable) -> None: ...
	def Restore(self, anAttribute: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(atLabel: TDF_Label) -> TDocStd_XLink: ...
	def Update(self) -> TDF_Reference: ...

class TDocStd_XLinkIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, D: TDocStd_Document) -> None: ...
	def Initialize(self, D: TDocStd_Document) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self) -> TDocStd_XLinkPtr: ...

class TDocStd_XLinkRoot(TDF_Attribute):
	def BackupCopy(self) -> TDF_Attribute: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def Insert(anXLinkPtr: TDocStd_XLinkPtr) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, intoAttribute: TDF_Attribute, aRelocationTable: TDF_RelocationTable) -> None: ...
	@staticmethod
	def Remove(anXLinkPtr: TDocStd_XLinkPtr) -> None: ...
	def Restore(self, anAttribute: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(aDF: TDF_Data) -> TDocStd_XLinkRoot: ...

class TDocStd_XLinkTool:
	def __init__(self) -> None: ...
	def Copy(self, intarget: TDF_Label, fromsource: TDF_Label) -> None: ...
	def CopyWithLink(self, intarget: TDF_Label, fromsource: TDF_Label) -> None: ...
	def DataSet(self) -> TDF_DataSet: ...
	def IsDone(self) -> bool: ...
	def RelocationTable(self) -> TDF_RelocationTable: ...
	def UpdateLink(self, L: TDF_Label) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

tdocstd_IDList = tdocstd.IDList
TDocStd_Document_Get = TDocStd_Document.Get
TDocStd_Modified_Add = TDocStd_Modified.Add
TDocStd_Modified_Clear = TDocStd_Modified.Clear
TDocStd_Modified_Contains = TDocStd_Modified.Contains
TDocStd_Modified_Get = TDocStd_Modified.Get
TDocStd_Modified_GetID = TDocStd_Modified.GetID
TDocStd_Modified_IsEmpty = TDocStd_Modified.IsEmpty
TDocStd_Modified_Remove = TDocStd_Modified.Remove
TDocStd_Owner_GetDocument = TDocStd_Owner.GetDocument
TDocStd_Owner_GetID = TDocStd_Owner.GetID
TDocStd_Owner_SetDocument = TDocStd_Owner.SetDocument
TDocStd_Owner_SetDocument = TDocStd_Owner.SetDocument
TDocStd_XLink_GetID = TDocStd_XLink.GetID
TDocStd_XLink_Set = TDocStd_XLink.Set
TDocStd_XLinkRoot_GetID = TDocStd_XLinkRoot.GetID
TDocStd_XLinkRoot_Insert = TDocStd_XLinkRoot.Insert
TDocStd_XLinkRoot_Remove = TDocStd_XLinkRoot.Remove
TDocStd_XLinkRoot_Set = TDocStd_XLinkRoot.Set



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.math import *
from OCC.Core.TColgp import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *


class AppParCurves_Array1OfConstraintCouple:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> AppParCurves_ConstraintCouple: ...
    def __setitem__(self, index: int, value: AppParCurves_ConstraintCouple) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[AppParCurves_ConstraintCouple]: ...
    def next(self) -> AppParCurves_ConstraintCouple: ...
    __next__ = next
    def Init(self, theValue: AppParCurves_ConstraintCouple) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> AppParCurves_ConstraintCouple: ...
    def Last(self) -> AppParCurves_ConstraintCouple: ...
    def Value(self, theIndex: int) -> AppParCurves_ConstraintCouple: ...
    def SetValue(self, theIndex: int, theValue: AppParCurves_ConstraintCouple) -> None: ...

class AppParCurves_Array1OfMultiBSpCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> AppParCurves_MultiBSpCurve: ...
    def __setitem__(self, index: int, value: AppParCurves_MultiBSpCurve) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[AppParCurves_MultiBSpCurve]: ...
    def next(self) -> AppParCurves_MultiBSpCurve: ...
    __next__ = next
    def Init(self, theValue: AppParCurves_MultiBSpCurve) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> AppParCurves_MultiBSpCurve: ...
    def Last(self) -> AppParCurves_MultiBSpCurve: ...
    def Value(self, theIndex: int) -> AppParCurves_MultiBSpCurve: ...
    def SetValue(self, theIndex: int, theValue: AppParCurves_MultiBSpCurve) -> None: ...

class AppParCurves_Array1OfMultiCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> AppParCurves_MultiCurve: ...
    def __setitem__(self, index: int, value: AppParCurves_MultiCurve) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[AppParCurves_MultiCurve]: ...
    def next(self) -> AppParCurves_MultiCurve: ...
    __next__ = next
    def Init(self, theValue: AppParCurves_MultiCurve) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> AppParCurves_MultiCurve: ...
    def Last(self) -> AppParCurves_MultiCurve: ...
    def Value(self, theIndex: int) -> AppParCurves_MultiCurve: ...
    def SetValue(self, theIndex: int, theValue: AppParCurves_MultiCurve) -> None: ...

class AppParCurves_Array1OfMultiPoint:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> AppParCurves_MultiPoint: ...
    def __setitem__(self, index: int, value: AppParCurves_MultiPoint) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[AppParCurves_MultiPoint]: ...
    def next(self) -> AppParCurves_MultiPoint: ...
    __next__ = next
    def Init(self, theValue: AppParCurves_MultiPoint) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> AppParCurves_MultiPoint: ...
    def Last(self) -> AppParCurves_MultiPoint: ...
    def Value(self, theIndex: int) -> AppParCurves_MultiPoint: ...
    def SetValue(self, theIndex: int, theValue: AppParCurves_MultiPoint) -> None: ...

class AppParCurves_SequenceOfMultiBSpCurve:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> AppParCurves_MultiBSpCurve: ...
    def Last(self) -> AppParCurves_MultiBSpCurve: ...
    def Length(self) -> int: ...
    def Append(self, theItem: AppParCurves_MultiBSpCurve) -> AppParCurves_MultiBSpCurve: ...
    def Prepend(self, theItem: AppParCurves_MultiBSpCurve) -> AppParCurves_MultiBSpCurve: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> AppParCurves_MultiBSpCurve: ...
    def SetValue(self, theIndex: int, theValue: AppParCurves_MultiBSpCurve) -> None: ...

class AppParCurves_SequenceOfMultiCurve:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> AppParCurves_MultiCurve: ...
    def Last(self) -> AppParCurves_MultiCurve: ...
    def Length(self) -> int: ...
    def Append(self, theItem: AppParCurves_MultiCurve) -> AppParCurves_MultiCurve: ...
    def Prepend(self, theItem: AppParCurves_MultiCurve) -> AppParCurves_MultiCurve: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> AppParCurves_MultiCurve: ...
    def SetValue(self, theIndex: int, theValue: AppParCurves_MultiCurve) -> None: ...

class AppParCurves_Constraint(IntEnum):
	AppParCurves_NoConstraint: int = ...
	AppParCurves_PassPoint: int = ...
	AppParCurves_TangencyPoint: int = ...
	AppParCurves_CurvaturePoint: int = ...
AppParCurves_NoConstraint = AppParCurves_Constraint.AppParCurves_NoConstraint
AppParCurves_PassPoint = AppParCurves_Constraint.AppParCurves_PassPoint
AppParCurves_TangencyPoint = AppParCurves_Constraint.AppParCurves_TangencyPoint
AppParCurves_CurvaturePoint = AppParCurves_Constraint.AppParCurves_CurvaturePoint

class appparcurves:
	@staticmethod
	def Bernstein(NbPoles: int, U: math_Vector, A: math_Matrix, DA: math_Matrix) -> None: ...
	@staticmethod
	def BernsteinMatrix(NbPoles: int, U: math_Vector, A: math_Matrix) -> None: ...
	@staticmethod
	def SecondDerivativeBernstein(U: float, DDA: math_Vector) -> None: ...
	@staticmethod
	def SplineFunction(NbPoles: int, Degree: int, Parameters: math_Vector, FlatKnots: math_Vector, A: math_Matrix, DA: math_Matrix, Index: math_IntegerVector) -> None: ...

class AppParCurves_ConstraintCouple:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, TheIndex: int, Cons: AppParCurves_Constraint) -> None: ...
	def Constraint(self) -> AppParCurves_Constraint: ...
	def Index(self) -> int: ...
	def SetConstraint(self, Cons: AppParCurves_Constraint) -> None: ...
	def SetIndex(self, TheIndex: int) -> None: ...

class AppParCurves_MultiCurve:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, NbPol: int) -> None: ...
	@overload
	def __init__(self, tabMU: AppParCurves_Array1OfMultiPoint) -> None: ...
	@overload
	def Curve(self, CuIndex: int, TabPnt: TColgp_Array1OfPnt) -> None: ...
	@overload
	def Curve(self, CuIndex: int, TabPnt: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	def D1(self, CuIndex: int, U: float, Pt: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	def D1(self, CuIndex: int, U: float, Pt: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	def D2(self, CuIndex: int, U: float, Pt: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	def D2(self, CuIndex: int, U: float, Pt: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def Degree(self) -> int: ...
	def Dimension(self, CuIndex: int) -> int: ...
	def NbCurves(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Pole(self, CuIndex: int, Nieme: int) -> gp_Pnt: ...
	def Pole2d(self, CuIndex: int, Nieme: int) -> gp_Pnt2d: ...
	def SetNbPoles(self, nbPoles: int) -> None: ...
	def SetValue(self, Index: int, MPoint: AppParCurves_MultiPoint) -> None: ...
	def Transform(self, CuIndex: int, x: float, dx: float, y: float, dy: float, z: float, dz: float) -> None: ...
	def Transform2d(self, CuIndex: int, x: float, dx: float, y: float, dy: float) -> None: ...
	@overload
	def Value(self, Index: int) -> AppParCurves_MultiPoint: ...
	@overload
	def Value(self, CuIndex: int, U: float, Pt: gp_Pnt) -> None: ...
	@overload
	def Value(self, CuIndex: int, U: float, Pt: gp_Pnt2d) -> None: ...

class AppParCurves_MultiPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, NbPoints: int, NbPoints2d: int) -> None: ...
	@overload
	def __init__(self, tabP: TColgp_Array1OfPnt) -> None: ...
	@overload
	def __init__(self, tabP2d: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	def __init__(self, tabP: TColgp_Array1OfPnt, tabP2d: TColgp_Array1OfPnt2d) -> None: ...
	def Dimension(self, Index: int) -> int: ...
	def NbPoints(self) -> int: ...
	def NbPoints2d(self) -> int: ...
	def Point(self, Index: int) -> gp_Pnt: ...
	def Point2d(self, Index: int) -> gp_Pnt2d: ...
	def SetPoint(self, Index: int, Point: gp_Pnt) -> None: ...
	def SetPoint2d(self, Index: int, Point: gp_Pnt2d) -> None: ...
	def Transform(self, CuIndex: int, x: float, dx: float, y: float, dy: float, z: float, dz: float) -> None: ...
	def Transform2d(self, CuIndex: int, x: float, dx: float, y: float, dy: float) -> None: ...

class AppParCurves_MultiBSpCurve(AppParCurves_MultiCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, NbPol: int) -> None: ...
	@overload
	def __init__(self, tabMU: AppParCurves_Array1OfMultiPoint, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> None: ...
	@overload
	def __init__(self, SC: AppParCurves_MultiCurve, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> None: ...
	@overload
	def D1(self, CuIndex: int, U: float, Pt: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	def D1(self, CuIndex: int, U: float, Pt: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	def D2(self, CuIndex: int, U: float, Pt: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	def D2(self, CuIndex: int, U: float, Pt: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def Degree(self) -> int: ...
	def Knots(self) -> TColStd_Array1OfReal: ...
	def Multiplicities(self) -> TColStd_Array1OfInteger: ...
	def SetKnots(self, theKnots: TColStd_Array1OfReal) -> None: ...
	def SetMultiplicities(self, theMults: TColStd_Array1OfInteger) -> None: ...
	@overload
	def Value(self, CuIndex: int, U: float, Pt: gp_Pnt) -> None: ...
	@overload
	def Value(self, CuIndex: int, U: float, Pt: gp_Pnt2d) -> None: ...

# harray1 classes

class AppParCurves_HArray1OfMultiCurve(AppParCurves_Array1OfMultiCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> AppParCurves_Array1OfMultiCurve: ...


class AppParCurves_HArray1OfConstraintCouple(AppParCurves_Array1OfConstraintCouple, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> AppParCurves_Array1OfConstraintCouple: ...


class AppParCurves_HArray1OfMultiPoint(AppParCurves_Array1OfMultiPoint, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> AppParCurves_Array1OfMultiPoint: ...


class AppParCurves_HArray1OfMultiBSpCurve(AppParCurves_Array1OfMultiBSpCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> AppParCurves_Array1OfMultiBSpCurve: ...

# harray2 classes
# hsequence classes

appparcurves_Bernstein = appparcurves.Bernstein
appparcurves_BernsteinMatrix = appparcurves.BernsteinMatrix
appparcurves_SecondDerivativeBernstein = appparcurves.SecondDerivativeBernstein
appparcurves_SplineFunction = appparcurves.SplineFunction



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class elslib:
	@staticmethod
	def ConeD0(U: float, V: float, Pos: gp_Ax3, Radius: float, SAngle: float, P: gp_Pnt) -> None: ...
	@staticmethod
	def ConeD1(U: float, V: float, Pos: gp_Ax3, Radius: float, SAngle: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@staticmethod
	def ConeD2(U: float, V: float, Pos: gp_Ax3, Radius: float, SAngle: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@staticmethod
	def ConeD3(U: float, V: float, Pos: gp_Ax3, Radius: float, SAngle: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@staticmethod
	def ConeDN(U: float, V: float, Pos: gp_Ax3, Radius: float, SAngle: float, Nu: int, Nv: int) -> gp_Vec: ...
	@staticmethod
	def ConeParameters(Pos: gp_Ax3, Radius: float, SAngle: float, P: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def ConeUIso(Pos: gp_Ax3, Radius: float, SAngle: float, U: float) -> gp_Lin: ...
	@staticmethod
	def ConeVIso(Pos: gp_Ax3, Radius: float, SAngle: float, V: float) -> gp_Circ: ...
	@staticmethod
	def ConeValue(U: float, V: float, Pos: gp_Ax3, Radius: float, SAngle: float) -> gp_Pnt: ...
	@staticmethod
	def CylinderD0(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt) -> None: ...
	@staticmethod
	def CylinderD1(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@staticmethod
	def CylinderD2(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@staticmethod
	def CylinderD3(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@staticmethod
	def CylinderDN(U: float, V: float, Pos: gp_Ax3, Radius: float, Nu: int, Nv: int) -> gp_Vec: ...
	@staticmethod
	def CylinderParameters(Pos: gp_Ax3, Radius: float, P: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def CylinderUIso(Pos: gp_Ax3, Radius: float, U: float) -> gp_Lin: ...
	@staticmethod
	def CylinderVIso(Pos: gp_Ax3, Radius: float, V: float) -> gp_Circ: ...
	@staticmethod
	def CylinderValue(U: float, V: float, Pos: gp_Ax3, Radius: float) -> gp_Pnt: ...
	@overload
	@staticmethod
	def D0(U: float, V: float, Pl: gp_Pln, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, V: float, C: gp_Cone, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, V: float, C: gp_Cylinder, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, V: float, S: gp_Sphere, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, V: float, T: gp_Torus, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, V: float, Pl: gp_Pln, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, V: float, C: gp_Cone, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, V: float, C: gp_Cylinder, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, V: float, S: gp_Sphere, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, V: float, T: gp_Torus, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, V: float, C: gp_Cone, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, V: float, C: gp_Cylinder, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, V: float, S: gp_Sphere, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, V: float, T: gp_Torus, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, V: float, C: gp_Cone, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, V: float, C: gp_Cylinder, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, V: float, S: gp_Sphere, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, V: float, T: gp_Torus, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def DN(U: float, V: float, Pl: gp_Pln, Nu: int, Nv: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, V: float, C: gp_Cone, Nu: int, Nv: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, V: float, C: gp_Cylinder, Nu: int, Nv: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, V: float, S: gp_Sphere, Nu: int, Nv: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, V: float, T: gp_Torus, Nu: int, Nv: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def Parameters(Pl: gp_Pln, P: gp_Pnt) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Parameters(C: gp_Cylinder, P: gp_Pnt) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Parameters(C: gp_Cone, P: gp_Pnt) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Parameters(S: gp_Sphere, P: gp_Pnt) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Parameters(T: gp_Torus, P: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def PlaneD0(U: float, V: float, Pos: gp_Ax3, P: gp_Pnt) -> None: ...
	@staticmethod
	def PlaneD1(U: float, V: float, Pos: gp_Ax3, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@staticmethod
	def PlaneDN(U: float, V: float, Pos: gp_Ax3, Nu: int, Nv: int) -> gp_Vec: ...
	@staticmethod
	def PlaneParameters(Pos: gp_Ax3, P: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def PlaneUIso(Pos: gp_Ax3, U: float) -> gp_Lin: ...
	@staticmethod
	def PlaneVIso(Pos: gp_Ax3, V: float) -> gp_Lin: ...
	@staticmethod
	def PlaneValue(U: float, V: float, Pos: gp_Ax3) -> gp_Pnt: ...
	@staticmethod
	def SphereD0(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt) -> None: ...
	@staticmethod
	def SphereD1(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@staticmethod
	def SphereD2(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@staticmethod
	def SphereD3(U: float, V: float, Pos: gp_Ax3, Radius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@staticmethod
	def SphereDN(U: float, V: float, Pos: gp_Ax3, Radius: float, Nu: int, Nv: int) -> gp_Vec: ...
	@staticmethod
	def SphereParameters(Pos: gp_Ax3, Radius: float, P: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def SphereUIso(Pos: gp_Ax3, Radius: float, U: float) -> gp_Circ: ...
	@staticmethod
	def SphereVIso(Pos: gp_Ax3, Radius: float, V: float) -> gp_Circ: ...
	@staticmethod
	def SphereValue(U: float, V: float, Pos: gp_Ax3, Radius: float) -> gp_Pnt: ...
	@staticmethod
	def TorusD0(U: float, V: float, Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, P: gp_Pnt) -> None: ...
	@staticmethod
	def TorusD1(U: float, V: float, Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec) -> None: ...
	@staticmethod
	def TorusD2(U: float, V: float, Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec) -> None: ...
	@staticmethod
	def TorusD3(U: float, V: float, Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, P: gp_Pnt, Vu: gp_Vec, Vv: gp_Vec, Vuu: gp_Vec, Vvv: gp_Vec, Vuv: gp_Vec, Vuuu: gp_Vec, Vvvv: gp_Vec, Vuuv: gp_Vec, Vuvv: gp_Vec) -> None: ...
	@staticmethod
	def TorusDN(U: float, V: float, Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, Nu: int, Nv: int) -> gp_Vec: ...
	@staticmethod
	def TorusParameters(Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, P: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def TorusUIso(Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, U: float) -> gp_Circ: ...
	@staticmethod
	def TorusVIso(Pos: gp_Ax3, MajorRadius: float, MinorRadius: float, V: float) -> gp_Circ: ...
	@staticmethod
	def TorusValue(U: float, V: float, Pos: gp_Ax3, MajorRadius: float, MinorRadius: float) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, V: float, Pl: gp_Pln) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, V: float, C: gp_Cone) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, V: float, C: gp_Cylinder) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, V: float, S: gp_Sphere) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, V: float, T: gp_Torus) -> gp_Pnt: ...

# harray1 classes
# harray2 classes
# hsequence classes

elslib_ConeD0 = elslib.ConeD0
elslib_ConeD1 = elslib.ConeD1
elslib_ConeD2 = elslib.ConeD2
elslib_ConeD3 = elslib.ConeD3
elslib_ConeDN = elslib.ConeDN
elslib_ConeParameters = elslib.ConeParameters
elslib_ConeUIso = elslib.ConeUIso
elslib_ConeVIso = elslib.ConeVIso
elslib_ConeValue = elslib.ConeValue
elslib_CylinderD0 = elslib.CylinderD0
elslib_CylinderD1 = elslib.CylinderD1
elslib_CylinderD2 = elslib.CylinderD2
elslib_CylinderD3 = elslib.CylinderD3
elslib_CylinderDN = elslib.CylinderDN
elslib_CylinderParameters = elslib.CylinderParameters
elslib_CylinderUIso = elslib.CylinderUIso
elslib_CylinderVIso = elslib.CylinderVIso
elslib_CylinderValue = elslib.CylinderValue
elslib_D0 = elslib.D0
elslib_D0 = elslib.D0
elslib_D0 = elslib.D0
elslib_D0 = elslib.D0
elslib_D0 = elslib.D0
elslib_D1 = elslib.D1
elslib_D1 = elslib.D1
elslib_D1 = elslib.D1
elslib_D1 = elslib.D1
elslib_D1 = elslib.D1
elslib_D2 = elslib.D2
elslib_D2 = elslib.D2
elslib_D2 = elslib.D2
elslib_D2 = elslib.D2
elslib_D3 = elslib.D3
elslib_D3 = elslib.D3
elslib_D3 = elslib.D3
elslib_D3 = elslib.D3
elslib_DN = elslib.DN
elslib_DN = elslib.DN
elslib_DN = elslib.DN
elslib_DN = elslib.DN
elslib_DN = elslib.DN
elslib_Parameters = elslib.Parameters
elslib_Parameters = elslib.Parameters
elslib_Parameters = elslib.Parameters
elslib_Parameters = elslib.Parameters
elslib_Parameters = elslib.Parameters
elslib_PlaneD0 = elslib.PlaneD0
elslib_PlaneD1 = elslib.PlaneD1
elslib_PlaneDN = elslib.PlaneDN
elslib_PlaneParameters = elslib.PlaneParameters
elslib_PlaneUIso = elslib.PlaneUIso
elslib_PlaneVIso = elslib.PlaneVIso
elslib_PlaneValue = elslib.PlaneValue
elslib_SphereD0 = elslib.SphereD0
elslib_SphereD1 = elslib.SphereD1
elslib_SphereD2 = elslib.SphereD2
elslib_SphereD3 = elslib.SphereD3
elslib_SphereDN = elslib.SphereDN
elslib_SphereParameters = elslib.SphereParameters
elslib_SphereUIso = elslib.SphereUIso
elslib_SphereVIso = elslib.SphereVIso
elslib_SphereValue = elslib.SphereValue
elslib_TorusD0 = elslib.TorusD0
elslib_TorusD1 = elslib.TorusD1
elslib_TorusD2 = elslib.TorusD2
elslib_TorusD3 = elslib.TorusD3
elslib_TorusDN = elslib.TorusDN
elslib_TorusParameters = elslib.TorusParameters
elslib_TorusUIso = elslib.TorusUIso
elslib_TorusVIso = elslib.TorusVIso
elslib_TorusValue = elslib.TorusValue
elslib_Value = elslib.Value
elslib_Value = elslib.Value
elslib_Value = elslib.Value
elslib_Value = elslib.Value
elslib_Value = elslib.Value



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *
from OCC.Core.Adaptor3d import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.Adaptor2d import *

BRepTopAdaptor_SeqOfPtr = NewType('BRepTopAdaptor_SeqOfPtr', TColStd_SequenceOfAddress)

class BRepTopAdaptor_FClass2d:
	def __init__(self, F: TopoDS_Face, Tol: float) -> None: ...
	def Copy(self, Other: BRepTopAdaptor_FClass2d) -> BRepTopAdaptor_FClass2d: ...
	def Destroy(self) -> None: ...
	def Perform(self, Puv: gp_Pnt2d, RecadreOnPeriodic: Optional[bool] = True) -> TopAbs_State: ...
	def PerformInfinitePoint(self) -> TopAbs_State: ...
	def TestOnRestriction(self, Puv: gp_Pnt2d, Tol: float, RecadreOnPeriodic: Optional[bool] = True) -> TopAbs_State: ...

class BRepTopAdaptor_HVertex(Adaptor3d_HVertex):
	def __init__(self, Vtx: TopoDS_Vertex, Curve: BRepAdaptor_HCurve2d) -> None: ...
	def ChangeVertex(self) -> TopoDS_Vertex: ...
	def IsSame(self, Other: Adaptor3d_HVertex) -> bool: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Parameter(self, C: Adaptor2d_HCurve2d) -> float: ...
	def Resolution(self, C: Adaptor2d_HCurve2d) -> float: ...
	def Value(self) -> gp_Pnt2d: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class BRepTopAdaptor_Tool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, Tol2d: float) -> None: ...
	@overload
	def __init__(self, Surface: Adaptor3d_HSurface, Tol2d: float) -> None: ...
	def Destroy(self) -> None: ...
	def GetSurface(self) -> Adaptor3d_HSurface: ...
	def GetTopolTool(self) -> BRepTopAdaptor_TopolTool: ...
	@overload
	def Init(self, F: TopoDS_Face, Tol2d: float) -> None: ...
	@overload
	def Init(self, Surface: Adaptor3d_HSurface, Tol2d: float) -> None: ...
	def SetTopolTool(self, TT: BRepTopAdaptor_TopolTool) -> None: ...

class BRepTopAdaptor_TopolTool(Adaptor3d_TopolTool):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Surface: Adaptor3d_HSurface) -> None: ...
	def Classify(self, P2d: gp_Pnt2d, Tol: float, RecadreOnPeriodic: Optional[bool] = True) -> TopAbs_State: ...
	def ComputeSamplePoints(self) -> None: ...
	def Destroy(self) -> None: ...
	def DomainIsInfinite(self) -> bool: ...
	def Edge(self) -> None: ...
	def Has3d(self) -> bool: ...
	def Init(self) -> None: ...
	def InitVertexIterator(self) -> None: ...
	@overload
	def Initialize(self) -> None: ...
	@overload
	def Initialize(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Initialize(self, Curve: Adaptor2d_HCurve2d) -> None: ...
	def IsThePointOn(self, P2d: gp_Pnt2d, Tol: float, RecadreOnPeriodic: Optional[bool] = True) -> bool: ...
	def More(self) -> bool: ...
	def MoreVertex(self) -> bool: ...
	def NbSamples(self) -> int: ...
	def NbSamplesU(self) -> int: ...
	def NbSamplesV(self) -> int: ...
	def Next(self) -> None: ...
	def NextVertex(self) -> None: ...
	@overload
	def Orientation(self, C: Adaptor2d_HCurve2d) -> TopAbs_Orientation: ...
	@overload
	def Orientation(self, C: Adaptor3d_HVertex) -> TopAbs_Orientation: ...
	def Pnt(self, V: Adaptor3d_HVertex) -> gp_Pnt: ...
	def SamplePoint(self, Index: int, P2d: gp_Pnt2d, P3d: gp_Pnt) -> None: ...
	@overload
	def Tol3d(self, C: Adaptor2d_HCurve2d) -> float: ...
	@overload
	def Tol3d(self, V: Adaptor3d_HVertex) -> float: ...
	def Value(self) -> Adaptor2d_HCurve2d: ...
	def Vertex(self) -> Adaptor3d_HVertex: ...

# harray1 classes
# harray2 classes
# hsequence classes

